@@ -2,11 +2,19 @@ use std::collections::LinkedList;
 
 use tokio::sync::Mutex;
 
-#[derive(Debug, Default)]
+#[derive(Debug)]
 pub struct AsyncList<T> {
     data: Mutex<LinkedList<T>>,
 }
 
+impl<T> Default for AsyncList<T> {
+    fn default() -> Self {
+        Self {
+            data: Mutex::new(LinkedList::new()),
+        }
+    }
+}
+
 impl<T> AsyncList<T> {
     pub async fn pop_front(&self) -> Option<T> {
         let mut guard = self.data.lock().await;
